;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "jtsx" "20251018.1908"
  "Extends JSX/TSX built-in support."
  '((emacs "29.1"))
  :url "https://github.com/llemaitre19/jtsx"
  :commit "61df071a7f4761ddb30c33c8225e78f72e68f7ae"
  :revdesc "61df071a7f47"
  :keywords '("languages")
  :authors '(("Loïc Lemaître" . "loic.lemaitre@gmail.com"))
  :maintainers '(("Loïc Lemaître" . "loic.lemaitre@gmail.com")))
